<%*
/** 
 * List of dictionaries/objects for each subclass are defined here. This the central place where to control all the properties.
  
 * common {array} contains common properties to all sub-classes. Contains three unnamed dictionaries. [0] contains the common properties at the top; [1] common properties at the bottom; [2] name of the main class.
 * main {array} contains attributes and frontmatter properties for each subclass. This array contains a flexible or dynamic number of dictionaries. As many as the user requires. Each dictionary correspond to a subclass. The mandatory keys are: name, prefix, folder, and fields. The other keys (exclude, dataview) are optional.
  
 * name:      name of the dictionary   
 * prefix:    prefix in note title
 * folder:    where the note is going to be moved
 * dataview:  a function that will return a Dataview table below the frontmatter
 * exclude:   an array of properties to exclude
 * fields:    Frontmatter properties

 */
const common = [
  { name: "CommonTop",
	prefix: "top",
	description: "Common properties at the top of frontmatter",
	fields: `
	    aliases: 
		type: 
		archetype: 
	  `
  }, 
  
  { name: "CommonBottom",
	prefix: "bot",
    description: "Common properties at the bottom of frontmatter",
	fields: `
		status: 
	    rating: 	
		summary: 
		up: 
		related: 
		uuid: 
		source: 
	  `
	},
	
	{ 
	  name: "config",
	  class: "Atlas",
	  template: "Atlas Super Template"
	}
]

const main = [
  { name: "Collection",
	prefix: "collect",
	exclude: ["source"],
	dataview: "getTableUpRelated()",
	folder: "Atlas/Collections",
    fields: `
		tags: map/collection
		archetype: "[[Collections]]"
    `
  },

  { name: "Company",
    prefix: "comp",
    exclude: ["rating", "source"],
    folder: "Atlas/Companies",
    dataview: "getTableUpRelated()",
    fields: `
	    industry: 
	    country: 
	    address: 
	    website: 
	    linkedin: 
		tags: map/company
		archetype: "[[Companies]]"
    `
  },
     
  { name: "Concept",
    prefix: "concept",
    exclude: ["source"],
    folder: "Atlas/Concepts",
    dataview: "getTableUpRelated()",
    fields: `
		tags: map/concept
		archetype: "[[Concepts]]"
    `
  },
  
  { name: "Discipline",
    prefix: "disc",
    exclude: ["rating", "source"],
    folder: "Atlas/Disciplines",
    fields: `
		tags: map/discipline
		archetype: "[[Disciplines]]"
    `
  },

  { name: "Event",
    prefix: "eve",
    folder: "Calendar/Events",
    fields: `
	    type: "[[event]]"
	    when: 
		tags: map/events
		archetype: "[[Calendar]]"
    `
  }, 

  { name: "Industry",
    prefix: "ind",
    exclude: ["rating", "source"],
    dataview: "getTableUpRelated()",
    folder: "Atlas/Industries",
    fields: `
		tags: map/industry
		archetype: "[[Industries]]"
    `
  },

  { name: "Location",
    prefix: "loc",
    exclude: ["status", "rating", "source"],
    dataview: "getTableUpRelated()", 
    folder: "Atlas/Locations",
    fields: `
	    country: 
	    state: 
	    region: 
		tags: map/location
		archetype: "[[Locations]]"
    `
  },

  { name: "Media",
    prefix: "med",
    exclude: ["up", "related", "rating", "source"],
    folder: "Atlas/Media",
    fields: `
		tags: map/media
		archetype: "[[Media]]"
    `
  },

  { name: "Object",
    prefix: "obj",
    exclude: ["status", "up", "related", "source"],
    folder: "Atlas/Objects",
    fields: `
		tags: map/object
		archetype: "[[Objects]]"
    `
  },

  { name: "People",
    prefix: "people",
    exclude: ["status", "rating", "source"],
    dataview: "getTableUpRelated()",
    folder: "Atlas/People",
    fields: `
	    known_for: 
	    company: 
	    BU:
	    position: 
	    role: 
	    reports_to: 
	    email: 
	    address: 
	    phone: 
	    city: 
	    linkedin: 
	    github: 
		tags: map/person
		archetype: "[[People]]"
    `
  },

  { name: "Private",
    prefix: "priv",
    exclude: ["rating", "summary", "status", "source"],
    folder: "Spaces/Private",
    fields: `
		tags: private
		archetype: "[[Private]]"  
    `
  },

  { name: "Rating",
    prefix: "rating",
    exclude: ["rating", "status", "up", "related", "source"],
    folder: "Atlas/Ratings",
    fields: `
		tags: map/rating
		archetype: "[[Ratings]]"  
    `
  },

  { name: "Realm",
    prefix: "realm",
    exclude: ["rating", "up", "related", "source"],
    folder: "Atlas/Realms",
    fields: `
		tags: map/realm
		archetype: "[[Realms]]"
    `
  },

  { name: "Status",
    prefix: "status",
    exclude: ["rating", "status", "up", "related", "source"],
    folder: "Atlas/Status",
    fields: `
		tags: map/status
		archetype: "[[Status]]"
    `
  },

  { name: "Type",
    prefix: "type",
    exclude: ["rating", "status", "up", "related", "source"],
    folder: "Atlas/Types",
    fields: `
		tags: map/type
		archetype: "[[Types]]"
    `
  },
]

let  atlasArray = []
atlasArray.common = common;
atlasArray.main = main;
return atlasArray;  // pass the named arrays to the master template

-%>